@@ -235,6 +235,68 @@ func Test_killCmd_SendInterrupt_false(t *testing.T) {
 	}
 }
 
+func Test_killCmd_KillsDetachedChildren(t *testing.T) {
+	if runtime.GOOS != "linux" {
+		t.Skip("requires /proc")
+	}
+
+	_, b, _, _ := runtime.Caller(0)
+	dir := filepath.Dir(b)
+	err := os.Chdir(dir)
+	if err != nil {
+		t.Fatalf("couldn't change directory: %v", err)
+	}
+
+	_ = os.Remove("pid")
+	defer os.Remove("pid")
+
+	e := Engine{
+		config: &Config{
+			Build: cfgBuild{
+				SendInterrupt: false,
+			},
+		},
+	}
+
+	startChan := make(chan *exec.Cmd)
+	go func() {
+		cmd, _, _, err := e.startCmd("sh _testdata/run-detached-process.sh")
+		if err != nil {
+			t.Errorf("failed to start command: %v", err)
+			return
+		}
+		startChan <- cmd
+		if err := cmd.Wait(); err != nil {
+			t.Logf("failed to wait command: %v", err)
+		}
+	}()
+
+	cmd := <-startChan
+	time.Sleep(2 * time.Second)
+
+	if _, err := e.killCmd(cmd); err != nil {
+		t.Fatalf("failed to kill command: %v", err)
+	}
+
+	bytesRead, err := os.ReadFile("pid")
+	require.NoError(t, err)
+	lines := strings.Split(string(bytesRead), "\n")
+	for _, line := range lines {
+		line = strings.TrimSpace(line)
+		if line == "" {
+			continue
+		}
+		if _, err := strconv.Atoi(line); err != nil {
+			t.Logf("failed to convert str to int %v", err)
+			continue
+		}
+		_, err = exec.Command("ps", "-p", line, "-o", "comm= ").Output()
+		if err == nil {
+			t.Fatalf("process should be killed %v", line)
+		}
+	}
+}
+
 func TestGetStructureFieldTagMap(t *testing.T) {
 	c := Config{}
 	tagMap := flatConfig(c)
